==> kdesdk_4.6.5.orig.tar.bz2: kdesdk-4.6.5/okteta/kasten/core/io/filesystem/externalbookmarkstorage.h <==
/*
    This file is part of the Okteta Kasten module, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef EXTERNALBOOKMARKSTORAGE_H
#define EXTERNALBOOKMARKSTORAGE_H

class KBookmarkManager;
class KUrl;


namespace Kasten
{
class ByteArrayDocument;

class ExternalBookmarkStorage
{
  public:
    ExternalBookmarkStorage();

    ~ExternalBookmarkStorage();

  public:
    void readBookmarks( ByteArrayDocument* document, const KUrl& url );
    void writeBookmarks( ByteArrayDocument* document, const KUrl& url );

  protected:
    KBookmarkManager* mBookmarkManager;
};

}

#endif

==> kdesdk-4.7.0.tar.bz2: kdesdk-4.7.0/okteta/kasten/core/io/filesystem/externalbookmarkstorage.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef EXTERNALBOOKMARKSTORAGE_H
#define EXTERNALBOOKMARKSTORAGE_H

class KBookmarkManager;
class KUrl;


namespace Kasten
{
class ByteArrayDocument;

class ExternalBookmarkStorage
{
  public:
    ExternalBookmarkStorage();

    ~ExternalBookmarkStorage();

  public:
    void readBookmarks( ByteArrayDocument* document, const KUrl& url );
    void writeBookmarks( ByteArrayDocument* document, const KUrl& url );

  protected:
    KBookmarkManager* mBookmarkManager;
};

}

#endif
